@@ -61,6 +61,7 @@ import javax.ws.rs.Produces;
 import javax.ws.rs.core.Context;
 import javax.ws.rs.core.MediaType;
 import javax.ws.rs.core.Response;
+import javax.ws.rs.core.Response.ResponseBuilder;
 
 import com.openexchange.java.Strings;
 import com.openexchange.mobile.api.facade.auth.AuthenticationService;
@@ -111,12 +112,17 @@ public class AuthenticationEndpoint {
         validate(authenticationRequestBody);
         String hostname = RequestUtil.getHostHeader(request);
         String userAgent = RequestUtil.getUserAgent(request);
+        String forwardedFor = RequestUtil.getForwardedForWithRemoteIp(request);
+        String proto = RequestUtil.getForwardedProto(request);
         String trackingId = RequestUtil.getTrackingId(request);
         HostConfiguration configuration = ConfigurationHelper.getConfiguration(hostname);
         RequestUtil.checkUserAgent(userAgent, configuration);
         LoginCredentials credentials = getCredentials(request, authenticationRequestBody)
+                .withHostConfiguration(configuration)
                 .withHost(hostname)
                 .withUserAgent(userAgent)
+                .withForwardedFor(forwardedFor)
+                .withForwardedProto(proto)
                 .withTrackingId(trackingId);
         try {
             AuthenticationService authenticationService = authenticationHandler.getAuthenticationService(configuration);
@@ -191,13 +197,14 @@ public class AuthenticationEndpoint {
         String rawResponseBody = JacksonUtil.toString(responseBody);
         Response.ResponseBuilder builder = Response.ok(rawResponseBody);
         CookieUtil.addToResponse(builder, sessionData.getCookies());
-        return builder.build();
+        return RequestUtil.nonCachable(builder).build();
     }
 
     @SneakyThrows
     private Response buildRedirectResponse(ApiFacadeException e) {
         String baseUrl = e.getMessage();
-        return Response.temporaryRedirect(new URI(baseUrl)).build();
+        ResponseBuilder builder = Response.temporaryRedirect(new URI(baseUrl));
+        return RequestUtil.nonCachable(builder).build();
     }
 
 }
